#
# spec file for package python-astral
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-astral
Version:        1.10.1
Release:        lp152.1.1
Summary:        Calculations for the position of the sun and moon
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/sffjunkie/astral
Source:         https://files.pythonhosted.org/packages/source/a/astral/astral-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pytz
Requires:       python-requests
BuildArch:      noarch
%python_subpackages

%description
This is 'astral' a Python module which calculates

* Times for various positions of the sun: dawn, sunrise, solar noon,
  sunset, dusk, solar elevation, solar azimuth and rahukaalam.
* The phase of the moon.

For documentation see the http://astral.readthedocs.io/en/latest/index.html

%prep
%setup -q -n astral-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}/%{$python_sitelib}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} py.test-%{$python_bin_suffix} -v -m "not webtest"

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.10.1:
  * Keywords arguments to Astral init are now passed to the geocoder
  * Added method to AstralGeocoder to add locations to the database
  * Version 1.9 broke the sun_utc method. Sun UTC calculation passed incorrect parameter
  * Corrected version number in module source code
  * Sun calculations now take into account the elevation of the location
  * Added command line interface to return sun information as json
- Run tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Nov 12 2018 Matěj Cepl <mcepl@suse.com>
- Make package buildable on Leap 42.* (SLE 12.*) as well.
* Mon Nov 12 2018 Adrian Schröter <adrian@suse.de>
- update to version 1.7.1
  * Requests is now only needed when using GoogleGeocoder
  * GoogleGeocoder now requires the `api_key` parameter to be passed to the constructor
* Mon May 14 2018 adrian@suse.de
- update to version 1.6.1
  * minor fixes
* Sun Mar  4 2018 alarrosa@suse.com
- Update to python-astral 1.6:
  * Added api_key parameter to GoogleGeocoder init method.
- Add LICENSE file from upstream's git.
* Mon Feb 12 2018 adrian@suse.de
- update to version 1.5
  * dawn_utc, sunrise_utc, sunset_utc and dusk_utc now only raise AstralError
    for a math domain exception all other exceptions are passed through.
  * moon_phase now takes another parameter if the type to return either
    int (the default) or float
* Mon Sep 11 2017 aloisio@gmx.com
- Update to version 1.4
- Converted to single-spec
* Wed Feb 22 2017 toms@opensuse.org
- First public release 1.3.4 on OBS
